[Vtigercrm-commits] [vtiger-commits] r7490 - in /vtigercrm/trunk/include/nusoap: class.soap_transport_http.php nusoapmime.php

vtigercrm-commits at vtiger.fosslabs.com vtigercrm-commits at vtiger.fosslabs.com
Sat Jun 24 15:50:13 EDT 2006


Author: mmbrich
Date: Sat Jun 24 13:50:12 2006
New Revision: 7490

Log:
hopefully the last SOAP fix

Modified:
    vtigercrm/trunk/include/nusoap/class.soap_transport_http.php
    vtigercrm/trunk/include/nusoap/nusoapmime.php

Modified: vtigercrm/trunk/include/nusoap/class.soap_transport_http.php
==============================================================================
--- vtigercrm/trunk/include/nusoap/class.soap_transport_http.php (original)
+++ vtigercrm/trunk/include/nusoap/class.soap_transport_http.php Sat Jun 24 13:50:12 2006
@@ -832,7 +832,7 @@
 			($http_status >= 400 && $http_status <= 417) ||
 			($http_status >= 501 && $http_status <= 505)
 		   ) {
-			$this->setError("Unsupported HTTP response status $http_status $http_reason (soapclient->response has contents of the response)");
+			$this->setError("Unsupported HTTP response status $http_status $http_reason (soapclient2->response has contents of the response)");
 			return false;
 		}
 
@@ -1035,4 +1035,4 @@
 }
 
 
-?>
+?>

Modified: vtigercrm/trunk/include/nusoap/nusoapmime.php
==============================================================================
--- vtigercrm/trunk/include/nusoap/nusoapmime.php (original)
+++ vtigercrm/trunk/include/nusoap/nusoapmime.php Sat Jun 24 13:50:12 2006
@@ -37,7 +37,7 @@
 require_once('Mail/mimePart.php');
 
 /**
 * soapclientmime client supporting MIME attachments defined at
 * http://www.w3.org/TR/SOAP-attachments.  It depends on the PEAR Mail_MIME library.
 *
 * @author   Scott Nichol <snichol at sourceforge.net>
@@ -45,7 +45,7 @@
 * @version  $Id: nusoapmime.php,v 1.7 2005/07/27 19:24:42 snichol Exp $
 * @access   public
 */
-class soapclientmime extends soapclient {
+class soapclient2mime extends soapclient2 {
 	/**
 	 * @var array Each array element in the return is an associative array with keys
 	 * data, filename, contenttype, cid
@@ -37,7 +37,7 @@
 
 /**
-* soapclientmime client supporting MIME attachments defined at
+* soapclient2mime client supporting MIME attachments defined at
 * http://www.w3.org/TR/SOAP-attachments.  It depends on the PEAR Mail_MIME library.
 *





More information about the vtigercrm-commits mailing list